@@ -2,7 +2,10 @@ import cv2 as cv
 
 
 def to_gray(frame, options=None):
-    gray = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
+    if frame is None:
+      return None
+      
+    gray = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)    
     return gray
 
 filter = {
